function four_interp,im,n,perc

; Este programa interpola una imagen por Fourier multiplicando su numero
; de muestras por n en cada dimension.
; El programa ejecuta mucho mas rapidamente si las dimensiones de la imagen
; interpolada resultante son potencia de 2 o suma de potencias de 2.
;
; INPUTS:
; 
; ima  = Imagen original a ser interpolada. Las dimensiones han de ser par.
; n    = Factor de interpolacion. Numero entero. El intervalo de muestreo 
;        en la imagen interpolada sera una fraccion 1./n del original.
; perc = porcentage para apodizar y asi conseguir mejor aproximacion a 
;	 espectro de frecuencia limitada. Para perc=0 no se apodiza.
;
; OUTPUTS:
;                 imi=four_interp(im,n,perc)
;
; NOTA.- Si el factor n es muy grande (ej. 16 o 20) el tama\~no de la 
;	 imagen "im" habra que adecuarlo a la capacidad de la memoria idl.
;	 Se puede ahorrar memoria si se trabaja en precision normal en vez 
;	 de double. Para ello habra que comentar adecuadamente las 
;	 3 sentencias marcadas con CCC. Es decir comentar la primera con ;
;	 e intercambiar el caracter ; en las otras dos
;
;
; Programa editado el 2 de Julio de 1998.
;
;------------------------------------------------------------------------------

  s=size(im) 
  nx=s(1) & ny=s(2) & nx2=nx/2 & ny2=ny/2
  nnx=n*nx & nny=n*ny & nnx2=nnx/2 & nny2=nny/2

; Prolonga n veces la imagen tranformada de Fourier

;  im=double(im)                          ;CCC
  win=win_cos(nx,ny,perc)
  if perc ne 0 then begin
    me=mean(im)
    fim=fft((im-me)*win+me,-1)
  endif else begin
    fim=fft(im,-1)
  endelse
  fim=shift(fim,nx2,ny2)
;  imi=dcomplexarr(nnx,nny)               ;CCC
  imi=complexarr(nnx,nny)               ;CCC
  imi(nnx2-nx2:nnx2+nx2-1,nny2-ny2:nny2+ny2-1)=fim(0:nx-1,0:ny-1)
  fim=0
  imi=shift(temporary(imi),-nnx2,-nny2)
  imi=float(fft(temporary(imi),1))
;  im=float(im)

; Visualizacion del resultado.
; Plot de una fila de la imagen interpolada y de la imagen original.
  
  window,0,xs=1100,ys=500
  plot,imi(*,nny2),yrange=[min(im),max(im)],$
   /yst,title='oplot de una fila en la imagen interp.(cont) y orig. (+)'
  oplot,findgen(nx)*n,im(*,ny2),psym=1
; la siguiente estadistica no demuestra la fiabilidad de las muestras
; interpoladas
;  dif=fltarr(nx,ny)
;  for i=0,nx-1 do for j=0,ny-1 do dif(i,j)=im(i,j)-imi(i*n,j*n)
;  print,'Estadistica de la diferencia imagen interpolada - imag.original
;  statist,dif

return,imi

end

